@@ -1,4 +1,4 @@
-from .nada import zilch
+from .nada import *
 
 def nothing():
     return "I told you, it does nothing."
